summaryrefslogtreecommitdiff
path: root/gr-wavelet/include/wavelet
diff options
context:
space:
mode:
authorJohnathan Corgan <jcorgan@corganenterprises.com>2012-04-13 23:04:06 -0700
committerJohnathan Corgan <jcorgan@corganenterprises.com>2012-04-21 13:20:39 -0700
commit9d56b9ba3b006e70f442001b54c66bcdb891a3b4 (patch)
tree2ca3379f5e5b714e16a363f07db7553559df7d7e /gr-wavelet/include/wavelet
parente717c7caeb04047c502f1447b0ea8be3dc4e8579 (diff)
wavelet: transition to namespace C++ API
Diffstat (limited to 'gr-wavelet/include/wavelet')
-rw-r--r--gr-wavelet/include/wavelet/CMakeLists.txt12
-rw-r--r--gr-wavelet/include/wavelet/api.h (renamed from gr-wavelet/include/wavelet/wavelet_api.h)0
-rw-r--r--gr-wavelet/include/wavelet/squash_ff.h (renamed from gr-wavelet/include/wavelet/wavelet_squash_ff.h)34
-rw-r--r--gr-wavelet/include/wavelet/wavelet_ff.h (renamed from gr-wavelet/include/wavelet/wavelet_wavelet_ff.h)35
-rw-r--r--gr-wavelet/include/wavelet/wvps_ff.h (renamed from gr-wavelet/include/wavelet/wavelet_wvps_ff.h)31
5 files changed, 65 insertions, 47 deletions
diff --git a/gr-wavelet/include/wavelet/CMakeLists.txt b/gr-wavelet/include/wavelet/CMakeLists.txt
index a37a3b0cd8..43c1603d15 100644
--- a/gr-wavelet/include/wavelet/CMakeLists.txt
+++ b/gr-wavelet/include/wavelet/CMakeLists.txt
@@ -1,4 +1,4 @@
-# Copyright 2011 Free Software Foundation, Inc.
+# Copyright 2012 Free Software Foundation, Inc.
#
# This file is part of GNU Radio
#
@@ -21,11 +21,11 @@
# Install header files
########################################################################
install(FILES
- wavelet_api.h
- wavelet_squash_ff.h
- wavelet_wavelet_ff.h
- wavelet_wvps_ff.h
- DESTINATION ${GR_INCLUDE_DIR}/gnuradio
+ api.h
+ squash_ff.h
+ wavelet_ff.h
+ wvps_ff.h
+ DESTINATION ${GR_INCLUDE_DIR}/gnuradio/wavelet
COMPONENT "wavelet_devel"
)
diff --git a/gr-wavelet/include/wavelet/wavelet_api.h b/gr-wavelet/include/wavelet/api.h
index 68b2c04d78..68b2c04d78 100644
--- a/gr-wavelet/include/wavelet/wavelet_api.h
+++ b/gr-wavelet/include/wavelet/api.h
diff --git a/gr-wavelet/include/wavelet/wavelet_squash_ff.h b/gr-wavelet/include/wavelet/squash_ff.h
index 5824969162..4d1aeb3c3c 100644
--- a/gr-wavelet/include/wavelet/wavelet_squash_ff.h
+++ b/gr-wavelet/include/wavelet/squash_ff.h
@@ -23,23 +23,29 @@
#ifndef INCLUDED_WAVELET_SQUASH_FF_H
#define INCLUDED_WAVELET_SQUASH_FF_H
-#include <wavelet_api.h>
+#include <wavelet/api.h>
#include <gr_sync_block.h>
-/*!
- * \brief implements cheap resampling of spectrum directly from
- * spectral points, using gsl interpolation
- * \ingroup misc
- */
-class wavelet_squash_ff;
-typedef boost::shared_ptr<wavelet_squash_ff> wavelet_squash_ff_sptr;
+namespace gr {
+ namespace wavelet {
-WAVELET_API wavelet_squash_ff_sptr wavelet_make_squash_ff(const std::vector<float> &igrid,
- const std::vector<float> &ogrid);
+ class WAVELET_API squash_ff : virtual public gr_sync_block
+ {
+ public:
+
+ // gr::wavelet::squash_ff::sptr
+ typedef boost::shared_ptr<squash_ff> sptr;
+
+ /*!
+ * \brief implements cheap resampling of spectrum directly from
+ * spectral points, using gsl interpolation
+ * \ingroup misc
+ */
+ static WAVELET_API sptr make(const std::vector<float> &igrid,
+ const std::vector<float> &ogrid);
+ };
-class WAVELET_API wavelet_squash_ff : virtual public gr_sync_block
-{
- // No public API methods visible
-};
+ } /* namespace wavelet */
+} /* namespace gr */
#endif
diff --git a/gr-wavelet/include/wavelet/wavelet_wavelet_ff.h b/gr-wavelet/include/wavelet/wavelet_ff.h
index 7d60dbdad1..71e959f88a 100644
--- a/gr-wavelet/include/wavelet/wavelet_wavelet_ff.h
+++ b/gr-wavelet/include/wavelet/wavelet_ff.h
@@ -19,28 +19,33 @@
* the Free Software Foundation, Inc., 51 Franklin Street,
* Boston, MA 02110-1301, USA.
*/
+
#ifndef INCLUDED_WAVELET_WAVELET_FF_H
#define INCLUDED_WAVELET_WAVELET_FF_H
-#include <wavelet_api.h>
+#include <wavelet/api.h>
#include <gr_sync_block.h>
-class wavelet_wavelet_ff;
-typedef boost::shared_ptr<wavelet_wavelet_ff> wavelet_wavelet_ff_sptr;
+namespace gr {
+ namespace wavelet {
-WAVELET_API wavelet_wavelet_ff_sptr
-wavelet_make_wavelet_ff(int size = 1024,
- int order = 20,
- bool forward = true);
+ class WAVELET_API wavelet_ff : virtual public gr_sync_block
+ {
+ public:
-/*!
- * \brief compute wavelet transform using gsl routines
- * \ingroup wavelet_blk
- */
+ // gr::wavelet::wavelet_ff:sptr
+ typedef boost::shared_ptr<wavelet_ff> sptr;
+
+ /*!
+ * \brief compute wavelet transform using gsl routines
+ * \ingroup wavelet_blk
+ */
+ static WAVELET_API sptr make(int size = 1024,
+ int order = 20,
+ bool forward = true);
+ };
-class WAVELET_API wavelet_wavelet_ff : virtual public gr_sync_block
-{
- // No public API methods visible
-};
+ } /* namespace wavelet */
+} /* namespace gr */
#endif /* INCLUDED_WAVELET_WAVELET_FF_H */
diff --git a/gr-wavelet/include/wavelet/wavelet_wvps_ff.h b/gr-wavelet/include/wavelet/wvps_ff.h
index 4e2889b52a..8b955db65f 100644
--- a/gr-wavelet/include/wavelet/wavelet_wvps_ff.h
+++ b/gr-wavelet/include/wavelet/wvps_ff.h
@@ -23,22 +23,29 @@
#ifndef INCLUDED_WAVELET_WVPS_FF_H
#define INCLUDED_WAVELET_WVPS_FF_H
-#include <wavelet_api.h>
+#include <wavelet/api.h>
#include <gr_sync_decimator.h>
class wavelet_wvps_ff;
-typedef boost::shared_ptr<wavelet_wvps_ff> wavelet_wvps_ff_sptr;
-WAVELET_API wavelet_wvps_ff_sptr
-wavelet_make_wvps_ff(int ilen);
+namespace gr {
+ namespace wavelet {
-/*!
- * \brief computes the Wavelet Power Spectrum from a set of wavelet coefficients
- * \ingroup wavelet_blk
- */
-class WAVELET_API wavelet_wvps_ff : virtual public gr_sync_block
-{
- // No public API methods visible
-};
+ class WAVELET_API wvps_ff : virtual public gr_sync_block
+ {
+ public:
+
+ // gr::wavelet::wvps_ff::sptr
+ typedef boost::shared_ptr<wvps_ff> sptr;
+
+ /*!
+ * \brief computes the Wavelet Power Spectrum from a set of wavelet coefficients
+ * \ingroup wavelet_blk
+ */
+ static WAVELET_API sptr make(int ilen);
+ };
+
+ } /* namespace wavelet */
+} /* namespace gr */
#endif /* INCLUDED_WAVELET_WVPS_FF_H */